/* *
 *    OPEN-XCHANGE legal information
 *
 *    All intellctual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.documentconverter.client.impl;

import java.net.URL;
import java.util.HashSet;
import java.util.Set;
import com.openexchange.documentconverter.Config;

/**
 * {@link Config}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */
/**
 * {@link ClientConfig}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */
public class ClientConfig implements Config {

    // DocumentConverter server

    /**
     * Server Base URL to be used for remote DocumentConverter conversions;
     * if left empty, no document conversions will be handled
     */
    public URL REMOTEURL_DOCUMENTCONVERTER = null;

    /**
     * the maximum size in Bytes for documents to be converted;
     * -1 for no upper limit; default is 128MB
     */
    public long MAX_DOCUMENT_SOURCEFILESIZE = 134217728;

    /**
     * the maximum size in MegaBytes for documents to be converted;
     * -1 for no upper limit; default is 32MB
     */
    public long MAX_IMAGE_SOURCEFILESIZE= 33554432;

    public boolean PREVIEW_ENABLE_CACHE_LOOKUP = true;

    /**
     * the list of supported extension types
     * or an empty set, if no extension
     * check should be performed
     */
    public Set<String> SUPPORTED_TYPES = new HashSet<>();

    // - Internally used properties --------------------------------------------

    /**
     * the location of the log
     */
    public String CLIENT_LOGFILE = null;

    /**
     * determines the amount and detail of logging data; 3 = errors, 2 = errors and warnings, 1 = errors and warnings and infos, 0 =
     * disabled
     */
    public String CLIENT_LOGLEVEL = null;

    /**
     * Internal flag to enable the debug mode
     */
    public boolean CLIENT_DEBUG = false;
}
